# flake8: noqa

# import apis into api package
from passageidentity.openapi_client.api.magic_links_api import MagicLinksApi
from passageidentity.openapi_client.api.tokens_api import TokensApi
from passageidentity.openapi_client.api.user_devices_api import UserDevicesApi
from passageidentity.openapi_client.api.users_api import UsersApi

