# coding: utf-8

# flake8: noqa
"""
    Passage Management API

    Passage's management API to manage your Passage apps and users.

    The version of the OpenAPI document: 1
    Contact: support@passage.id
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from passageidentity.openapi_client.models.apple_user_social_connection import AppleUserSocialConnection
from passageidentity.openapi_client.models.create_magic_link_request import CreateMagicLinkRequest
from passageidentity.openapi_client.models.create_user_args import CreateUserArgs
from passageidentity.openapi_client.models.github_user_social_connection import GithubUserSocialConnection
from passageidentity.openapi_client.models.google_user_social_connection import GoogleUserSocialConnection
from passageidentity.openapi_client.models.link import Link
from passageidentity.openapi_client.models.list_devices_response import ListDevicesResponse
from passageidentity.openapi_client.models.list_paginated_users_item import ListPaginatedUsersItem
from passageidentity.openapi_client.models.list_paginated_users_response import ListPaginatedUsersResponse
from passageidentity.openapi_client.models.magic_link import MagicLink
from passageidentity.openapi_client.models.magic_link_channel import MagicLinkChannel
from passageidentity.openapi_client.models.magic_link_language import MagicLinkLanguage
from passageidentity.openapi_client.models.magic_link_response import MagicLinkResponse
from passageidentity.openapi_client.models.magic_link_type import MagicLinkType
from passageidentity.openapi_client.models.model400_error import Model400Error
from passageidentity.openapi_client.models.model401_error import Model401Error
from passageidentity.openapi_client.models.model403_error import Model403Error
from passageidentity.openapi_client.models.model404_error import Model404Error
from passageidentity.openapi_client.models.model500_error import Model500Error
from passageidentity.openapi_client.models.nonce import Nonce
from passageidentity.openapi_client.models.paginated_links import PaginatedLinks
from passageidentity.openapi_client.models.passage_user import PassageUser
from passageidentity.openapi_client.models.social_connection_type import SocialConnectionType
from passageidentity.openapi_client.models.update_user_args import UpdateUserArgs
from passageidentity.openapi_client.models.user_event_action import UserEventAction
from passageidentity.openapi_client.models.user_event_status import UserEventStatus
from passageidentity.openapi_client.models.user_recent_event import UserRecentEvent
from passageidentity.openapi_client.models.user_response import UserResponse
from passageidentity.openapi_client.models.user_social_connections import UserSocialConnections
from passageidentity.openapi_client.models.user_status import UserStatus
from passageidentity.openapi_client.models.web_authn_devices import WebAuthnDevices
from passageidentity.openapi_client.models.web_authn_icons import WebAuthnIcons
from passageidentity.openapi_client.models.web_authn_type import WebAuthnType
